##  Resources
Ready to build a business capability map for your organization? Use the following reference documents to help you get set up an Application Landscape quickly and get into use cases like [Application Rationalization](https://help.sap.com/docs/leanix/ea/application-rationalization?locale=en-US&state=PRODUCTION&version=CLOUD "Application rationalization reduces costs, eliminates redundancies, and improves efficiency. Optimize your application landscape with this step-by-step approach.") or Post-Merger Integration.
  * [Best Practices to Define Business Capability Maps![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fen%2Fdownload%2Fbest-practices-to-define-business-capability-maps "https://www.leanix.net/en/download/best-practices-to-define-business-capability-maps") - Get tips and best practices for using business capabilities and for creating a complete overview of your company's functions.
  * [Business Capability Map Template![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fen%2Fresources%2Fbusiness-capability-map-library%2F%23%2FDefault "https://www.leanix.net/en/resources/business-capability-map-library/#/Default")- Access a reference business capability map that lists business capabilities from levels one to three.


YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
